[Qa-jenkins-scm] [jenkins.debian.net] 02/02: chroot-installation: also test parl-desktop* packages in sid and stretch

Holger Levsen holger at layer-acht.org
Tue Apr 25 12:26:20 UTC 2017


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 585496642ce34572d31b21487574743211153122
Author: Holger Levsen <holger at layer-acht.org>
Date:   Tue Apr 25 14:26:13 2017 +0200

    chroot-installation: also test parl-desktop* packages in sid and stretch
    
    Signed-off-by: Holger Levsen <holger at layer-acht.org>
---
 job-cfg/chroot-installation.yaml.py | 12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

diff --git a/job-cfg/chroot-installation.yaml.py b/job-cfg/chroot-installation.yaml.py
index 4719607..ce0a391 100755
--- a/job-cfg/chroot-installation.yaml.py
+++ b/job-cfg/chroot-installation.yaml.py
@@ -87,6 +87,10 @@ all_targets = [
    'education-thin-client-server',
    'education-roaming-workstation',
    'education-workstation',
+   'parl-desktop',
+   'parl-desktop-eu',
+   'parl-desktop-strict',
+   'parl-desktop-world',
    ]
 
 #
@@ -105,8 +109,8 @@ def is_target_in_distro(distro, target):
          # education-thin-client-server is obsolete since stretch…
          elif distro in ('sid', 'buster') and target == 'education-thin-client-server':
              return False
-         # education-lang-* packages only exist since stretch
-         elif distro in ('wheezy', 'jessie') and target[:15] == 'education-lang-':
+         # education-lang-* and parl-desktop* packages only exist since stretch
+         elif distro in ('wheezy', 'jessie') and (target[:15] == 'education-lang-' or target[:12] == 'parl-desktop'):
              return False
          return True
 
@@ -161,7 +165,9 @@ spoken_names = {
     'debconf-video': 'all packages relevant for the DebConf videoteam',
     }
 def get_spoken_name(target):
-    if target[:10] == 'education-':
+    if target[:12] == 'parl-desktop':
+         return 'the Debian Parl metapackage '+target
+    elif target[:13] == 'education-':
          return 'the Debian Edu metapackage '+target
     elif target in spoken_names:
          return spoken_names[target]

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list